fars_summarize_years: Summarise months in FARS data for a specified year

Description Usage Arguments Details Value Examples

View source: R/fars_functions.R

Description

Function that reads one or more csv files, converts them into tbl_df tables, extracts year and month information from these tables, counts the number of observations per month for each year and stores the result in a tbl_df table with one column per year.

Usage

1

Arguments

years

A numeric or vector with the year(s) used to select the csv files

Details

The function selects files with names containing one of the year(s) specified by the argument years.

fars_summarize_years is built on the fars_read_years function.

Value

This function returns a tbl_df table with one column per selected year.

Examples

1
2
3
4
5
## Not run: 
fars_summarize_years(2014)
fars_summarize_years(2013:2015)

## End(Not run)

ajsarradin/farsAJS documentation built on May 5, 2019, 8:17 a.m.