Description Usage Arguments Details Value Examples
View source: R/fars_functions.R
Function that reads one or more csv files, converts them into tbl_df tables, extracts year and month
information from these tables, counts the number of observations per month for each year and stores the result
in a tbl_df table with one column per year.
1 | fars_summarize_years(years)
|
years |
A numeric or vector with the year(s) used to select the csv files |
The function selects files with names containing one of the year(s) specified by the argument years.
fars_summarize_years is built on the fars_read_years function.
This function returns a tbl_df table with one column per selected year.
1 2 3 4 5 | ## Not run:
fars_summarize_years(2014)
fars_summarize_years(2013:2015)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.